@@ -73,6 +73,7 @@ ggdotplotstats <- function(data,
                            test.value.linetype = "dashed",
                            test.line.labeller = TRUE,
                            test.k = 0,
+                           ggplot.component = NULL,
                            messages = TRUE) {
   # ------------------------------ variable names ----------------------------
 
@@ -103,12 +104,13 @@ ggdotplotstats <- function(data,
       y = !!rlang::enquo(y)
     ) %>%
     dplyr::filter(.data = ., !is.na(x), !is.na(y)) %>%
+    dplyr::mutate(.data = ., y = droplevels(as.factor(y))) %>%
     tibble::as_tibble(x = .)
 
   # if the data hasn't already been summarized, do so
   data %<>%
     dplyr::group_by(.data = ., y) %>%
-    dplyr::summarise(.data = ., x = mean(x = x, na.rm = TRUE)) %>%
+    dplyr::summarise(.data = ., x = mean(x, na.rm = TRUE)) %>%
     dplyr::ungroup(x = .)
 
   # rank ordering the data
@@ -248,6 +250,12 @@ ggdotplotstats <- function(data,
       )
     )
 
+  # ---------------- adding ggplot component ---------------------------------
+
+  # if any additional modification needs to be made to the plot
+  # this is primarily useful for grouped_ variant of this function
+  plot <- plot + ggplot.component
+
   # ============================= messages =================================
 
   # display normality test result as a message
