@@ -1,8 +1,9 @@
-context("test_kw_eta_h_ci")
+context("kw_eta_h_ci")
 
 testthat::test_that(
-  desc = "Confidence interval for effect size for Kruskal-Wallis test ",
+  desc = "confidence interval for effect size for Kruskal-Wallis test ",
   code = {
+    testthat::skip_on_cran()
 
     # function output
     set.seed(123)
@@ -18,9 +19,9 @@ testthat::test_that(
 
 
     # testing 4 conditions
-    testthat::expect_equal(using_function1$eta_sq_H, 0.0765, tolerance = 0.0001)
-    testthat::expect_equal(using_function1$conf.low, 0.0540, tolerance = 0.0001)
-    testthat::expect_equal(using_function1$conf.high, 0.109, tolerance = 0.0003)
+    testthat::expect_equal(using_function1$eta_sq_H, 0.126, tolerance = 0.001)
+    testthat::expect_equal(using_function1$conf.low, 0.0978, tolerance = 0.0001)
+    testthat::expect_equal(using_function1$conf.high, 0.178, tolerance = 0.0003)
     testthat::expect_equal(using_function1$nboot, 50)
   }
 )
